@@ -40,6 +40,15 @@
 
 extern bool kde_kiosk_exception;
 
+static QByteArray lookup(const KConfigIniBackend::BufferFragment& fragment, QHash<KConfigIniBackend::BufferFragment, QByteArray>* cache)
+{
+    QHash<KConfigIniBackend::BufferFragment, QByteArray>::iterator it = cache->find(fragment);
+    if (it == cache->end()) {
+        it = cache->insert(fragment, fragment.toByteArray());
+    }
+    return it.value();
+}
+
 QString KConfigIniBackend::warningProlog(const QFile &file, int line)
 {
     return QString::fromLatin1("KConfigIni: In file %2, line %1: ")
@@ -62,6 +71,8 @@ KConfigBackend::ParseInfo
     return parseConfig(currentLocale, entryMap, options, false);
 }
 
+// merging==true is the merging that happens at the beginning of writeConfig:
+// merge changes in the on-disk file with the changes in the KConfig object.
 KConfigBackend::ParseInfo
 KConfigIniBackend::parseConfig(const QByteArray& currentLocale, KEntryMap& entryMap,
                                ParseOptions options, bool merging)
@@ -92,6 +103,14 @@ KConfigIniBackend::parseConfig(const QByteArray& currentLocale, KEntryMap& entry
     unsigned int len = contents.length();
     unsigned int startOfLine = 0;
 
+    // Reduce memory overhead by making use of implicit sharing
+    // This assumes that config files contain only a small amount of
+    // different fragments which are repeated often.
+    // This is often the case, especially sub groups will all have
+    // the same list of keys and similar values as well.
+    QHash<BufferFragment, QByteArray> cache;
+    cache.reserve(4096);
+
     while (startOfLine < len) {
         BufferFragment line = contents.split('\n', &startOfLine);
         line.trim();
@@ -243,9 +262,9 @@ KConfigIniBackend::parseConfig(const QByteArray& currentLocale, KEntryMap& entry
                 rawKey.reserve(aKey.length() + locale.length() + 2);
                 rawKey.append(aKey.toVolatileByteArray());
                 rawKey.append('[').append(locale.toVolatileByteArray()).append(']');
-                entryMap.setEntry(currentGroup, rawKey, line.toByteArray(), entryOptions);
+                entryMap.setEntry(currentGroup, rawKey, lookup(line, &cache), entryOptions);
             } else {
-                entryMap.setEntry(currentGroup, aKey.toByteArray(), line.toByteArray(), entryOptions);
+                entryMap.setEntry(currentGroup, lookup(aKey, &cache), lookup(line, &cache), entryOptions);
             }
         }
 next_line:
@@ -367,6 +386,7 @@ bool KConfigIniBackend::writeConfig(const QByteArray& locale, KEntryMap& entryMa
     const bool bGlobal = options & WriteGlobal;
 
     // First, reparse the file on disk, to merge our changes with the ones done by other apps
+    // Store the result into writeMap.
     {
         ParseOptions opts = ParseExpansions;
         if (bGlobal)
@@ -385,7 +405,9 @@ bool KConfigIniBackend::writeConfig(const QByteArray& locale, KEntryMap& entryMa
 
         // only write entries that have the same "globality" as the file
         if (it->bGlobal == bGlobal) {
-            if (!it->bDeleted) {
+            if (it->bReverted) {
+                writeMap.remove(key);
+            } else if (!it->bDeleted) {
                 writeMap[key] = *it;
             } else {
                 KEntryKey defaultKey = key;
